@@ -1,5 +1,6 @@
 import argparse
 import sys
+import os
 
 import pymuxinator.config as config
 from pymuxinator.project import Project
@@ -11,15 +12,26 @@ def main():
 
 
 class CLI(object):
+    valid_commands = (
+        ('commands', 'list commands',),
+        ('start', 'start project',),
+        ('list', 'list all projects',),
+    )
+
     def __init__(self):
         parser = argparse.ArgumentParser(description='Pymuxinator')
-        subparsers = parser.add_subparsers(title='commands', description='valid commands')
+        sub_parsers = parser.add_subparsers(title='commands', description='valid commands')
 
-        # add start
-        start = subparsers.add_parser('start', help='start')
-        start.add_argument('project', help='pymuxinator project to start')
-        start.add_argument('--preview', dest='preview', action='store_true', help='preview tmux commands')
-        start.set_defaults(func=self.start)
+        for command, help_text in self.valid_commands:
+            if hasattr(self, command):
+                sub_parser = sub_parsers.add_parser(command, help=help_text or '')
+
+                # add arguments to sub_parser
+                if hasattr(self, '_' + command):
+                    getattr(self, '_' + command)(sub_parser)
+
+                # set default function for sub_parser
+                sub_parser.set_defaults(func=getattr(self, command))
 
         if len(sys.argv) <= 1:
             parser.print_help()
@@ -27,6 +39,10 @@ class CLI(object):
             args = parser.parse_args()
             args.func(args)
 
+    def _start(self, parser):
+        parser.add_argument('project', help='pymuxinator project to start')
+        parser.add_argument('--preview', dest='preview', action='store_true', help='preview tmux commands')
+
     def start(self, args):
         project_name = args.project
         project = None
@@ -48,3 +64,18 @@ class CLI(object):
                 print commands
             else:
                 utils.execute_cmd(commands)
+
+    def commands(self, args):
+        commands = list(self.valid_commands)
+        commands = sorted(commands, key=lambda x: x[0])
+
+        for command, help_text in commands:
+            print command
+
+    def list(self, args):
+        configs = config.list_all()
+
+        for config_file in configs:
+            base = os.path.basename(config_file)
+            print os.path.splitext(base)[0]
+
